DcqlCredentialSetBuilder class

Inheritance

Constructors

DcqlCredentialSetBuilder(DcqlBuilder parent, CredentialSet _credentialSet)

Properties

$_ DcqlCredentialSetBuilder
Separator, returns the current builder instance.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
query DcqlQuery
The DCQL query being built.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validator DcqlValidator
latefinalinherited

Methods

build({bool skipValidation = false}) DcqlQuery
Builds the DCQL query. If skipValidation is false, the query will be validated before building. Throws a ValidationException if the query is invalid.
inherited
credential(String id, {Format? format, CredentialType? type}) DcqlCredentialBuilder
Adds a new credential to the query.
inherited
credentialSet({bool? required, List<List<String>>? options}) DcqlCredentialSetBuilder
Adds a new credential set to the query.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
option(List<String> option) DcqlCredentialSetBuilder
Adds an option to the credential set.
required([bool required = true]) DcqlCredentialSetBuilder
Sets whether this credential set is required.
toString() String
A string representation of this object.
inherited
validate() ValidationResult
Validates the current state of the query. Returns a ValidationResult with a list of errors if invalid.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited