Claim class

Represents a claim requested from a credential.

Mixed-in types

Constructors

Claim({String? id, required List path, List<Object>? values})

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
An optional identifier for this claim.
final
path List
The path to the claim in the credential. Must not be empty. String / int / null values are allowed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<Object>?
A list of specific values requested for this claim.
final

Methods

copyWith({String? id, List<Object>? values}) Claim
Creates a copy of this claim with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the object to a JSON-serializable value.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> claim) Claim