id property
An optional identifier for this claim.
This ID is used to reference the claim in Credential.claimSets.
Implementation
final String? id;
An optional identifier for this claim.
This ID is used to reference the claim in Credential.claimSets.
final String? id;