values property

List<Object>? values
final

A list of specific values requested for this claim.

If provided, the wallet should only return the claim if its value matches one of these values.

Implementation

final List<Object>? values;