Credential<C extends Claim> class

Mixed-in types

Constructors

Credential({required String id, Format format = Formats.sd_jwt, List<List<String>>? claimSets, bool? multiple, Meta? meta, List<C>? claims})
Format defaults to Formats.sd_jwt

Properties

claims ↔ List<C>?
A list of claims to request from the credential.
getter/setter pair
claimSets ↔ List<List<String>>?
A list of claim sets, where each claim set is a list of claim IDs.
getter/setter pair
format ↔ Format
The format of the credential (e.g., mdoc, sd_jwt, etc.) Defaults to Format.sd_jwt
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
A unique identifier for this credential query.
getter/setter pair
meta ↔ Meta
Metadata about the credential, such as the document type.
getter/setter pair
multiple ↔ bool?
Whether multiple credentials matching this query can be returned.
getter/setter pair
requireCryptographicHolderBinding ↔ bool?
Whether cryptographic holder binding is required.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trustedAuthorities ↔ List<TrustedAuthority>?
A list of trusted authorities (issuers) for this credential.
getter/setter pair

Methods

addClaim(C claim) → Credential<C>
Adds a claim to the credential and returns the updated credential.
addClaimSet(List<String> ids) → Credential<C>
Adds a claim set to the credential and returns the updated credential.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeClaim(C claim) → Credential<C>
Removes a claim from the credential and returns the updated credential.
removeClaimSet(List<String> ids) → Credential<C>
Removes a claim set from the credential and returns the updated credential.
toJson() → Map<String, dynamic>
Converts the object to a JSON-serializable value.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> c) → Credential<Claim>