addClaim method
Adds a claim to the credential and returns the updated credential.
Implementation
Credential<C> addClaim(C claim) {
claims ??= [];
claims?.add(claim);
return this;
}
Adds a claim to the credential and returns the updated credential.
Credential<C> addClaim(C claim) {
claims ??= [];
claims?.add(claim);
return this;
}