addClaimSet method
Adds a claim set to the credential and returns the updated credential.
Implementation
Credential<C> addClaimSet(List<String> ids) {
claimSets ??= [];
claimSets!.add(ids);
return this;
}
Adds a claim set to the credential and returns the updated credential.
Credential<C> addClaimSet(List<String> ids) {
claimSets ??= [];
claimSets!.add(ids);
return this;
}