id property
A unique identifier for this credential query.
This ID is used to reference the credential in CredentialSets.
Implementation
String id;
A unique identifier for this credential query.
This ID is used to reference the credential in CredentialSets.
String id;