removeClaim method
Removes a claim from the credential and returns the updated credential.
Implementation
Credential<C> removeClaim(C claim) {
if (claims == null) return this;
claims?.remove(claim);
return this;
}
Removes a claim from the credential and returns the updated credential.
Credential<C> removeClaim(C claim) {
if (claims == null) return this;
claims?.remove(claim);
return this;
}