options property

List<List<String>> options
getter/setter pair

A list of options, where each option is a list of credential IDs.

To satisfy the credential set, at least one of the options must be satisfied. An option is satisfied if all credentials in the list are returned.

Implementation

List<List<String>> options;