DcqlQuery class

Represents a DCQL (Digital Credentials Query Language) query.

A DCQL query is used to request specific credentials and claims from a wallet. It consists of a list of credentials and optional credentialSets that define the logic for satisfying the query.

Mixed-in types

Constructors

DcqlQuery({List<Credential<Claim>>? credentials, List<CredentialSet>? credentialSets})

Properties

credentials List<Credential<Claim>>
A list of credentials to request.
final
credentialSets List<CredentialSet>?
A list of credential sets that define combinations of credentials that satisfy the query.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCredential(Credential<Claim> credential) DcqlQuery
Adds a credential to the query.
addCredentialSet(CredentialSet credentialSet) DcqlQuery
Adds a credentialSet to the query.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeCredential(Credential<Claim> credential) bool
Removes a credential from the query.
removeCredentialSet(CredentialSet credentialSet) bool
Removes a credentialSet from the query.
toJson() Map<String, dynamic>
Converts the object to a JSON-serializable value.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) DcqlQuery