credentialSets property

List<CredentialSet>? credentialSets
getter/setter pair

A list of credential sets that define combinations of credentials that satisfy the query.

If null or empty, all credentials in credentials are required.

Implementation

List<CredentialSet>? credentialSets;