removeCredential method
Removes a credential from the query.
Returns true if the credential was in the list, false otherwise.
Implementation
bool removeCredential(Credential credential) {
return credentials.remove(credential);
}
Removes a credential from the query.
Returns true if the credential was in the list, false otherwise.
bool removeCredential(Credential credential) {
return credentials.remove(credential);
}