CredentialType class

Class for holding format / doctype relationships

Mixed-in types

Constructors

CredentialType({required Format format, required DocType docType})
const

Properties

docType DocType
final
format Format
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → dynamic
Converts the object to a JSON-serializable value.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited