DocTypes class abstract

Constructors

DocTypes()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

ageOver18 → const DocType
mDocMobileDrivingLicense → const DocType
https://credentials.walt.id/iso-mdoc-credentials/mdl-mobile-driving-licence
mDocMobileVehicleRegistration → const DocType
https://credentials.walt.id/iso-mdoc-credentials/mvrc-mobile-vehicle-registration
pidDe → const DocType
Common variation seen in German pilots
pidEuOfficial → const DocType
pidNl → const DocType
Common variation seen in Dutch pilots
pidPilot → const DocType
The shortened PID VCT used in many reference implementations and pilots. (This matches your working example)