Formats class abstract

Constructors

Formats()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

jwt → const Format
Alias for Format.sd_jwt
mdoc → const Format
Alias for Format.mso_mdoc
mso_mdoc → const Format
sd_jwt → const Format
values → const List<Format>
w3c → const Format