Meta class
Defines the metadata of a DCQL request.
Metadata can include information like the document type or other format-specific properties.
- Mixed-in types
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → Meta - Clears all metadata.
-
get(
String key) → dynamic - Gets a metadata value by key.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String key) → Meta - Removes a metadata value.
-
set(
String key, dynamic value) → Meta - Sets a metadata value.
-
setDocType(
DocType docType) → Meta -
Available on Meta, provided by the MetaSetFilterExtension extension
-
setFilter(
CredentialType type) → Meta -
Available on Meta, provided by the MetaSetFilterExtension extension
-
setVctValues(
List< String> vctValues) → Meta -
Available on Meta, provided by the MetaSetFilterExtension extension
-
toJson(
) → Map< String, dynamic> -
Converts the object to a JSON-serializable value.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited