ValidationException class

An exception thrown when a DCQL query is invalid.

Implemented types

Constructors

ValidationException(ValidationResult result)

Properties

hashCode → int
The hash code for this object.
no setterinherited
result → ValidationResult
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited