ValidationResult class

The result of a DCQL query validation.

Constructors

ValidationResult({String? contextPath, bool isValid = true, List<String> errors = const []})
ValidationResult.invalid({String? contextPath, List<String> errors = const []})
Creates an invalid result with a list of errors.
ValidationResult.valid({String? contextPath, List<String> errors = const []})
Creates a valid result.

Properties

contextPath String?
The path to the invalid field (e.g., query.credentials[0].id).
no setter
errors List<String>?
A list of error messages if the validation failed.
no setter
hashCode int
The hash code for this object.
no setterinherited
isInvalid bool
Returns true if the validation failed.
no setter
isValid bool
Returns true if the validation passed.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited