DcqlCredentialBuilder class
- Inheritance
-
- Object
- DcqlBuilder
- DcqlCredentialBuilder
Constructors
-
DcqlCredentialBuilder(DcqlBuilder parent, Credential<
Claim> _credential)
Properties
- $_ → DcqlCredentialBuilder
-
Separator, returns the current builder instance.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- query → DcqlQuery
-
The DCQL query being built.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validator ↔ DcqlValidator
-
latefinalinherited
Methods
-
build(
{bool skipValidation = false}) → DcqlQuery -
Builds the DCQL query.
If
skipValidationis false, the query will be validated before building. Throws a ValidationException if the query is invalid.inherited -
claim(
Claim claim, {String? id}) → DcqlCredentialBuilder - Adds a claim to the credential.
-
claimSet(
List< String> ids) → DcqlCredentialBuilder - Adds a claim set to the credential.
-
credential(
String id, {Format? format, CredentialType? type}) → DcqlCredentialBuilder -
Adds a new credential to the query.
inherited
-
credentialSet(
{bool? required, List< List< ? options}) → DcqlCredentialSetBuilderString> > -
Adds a new credential set to the query.
inherited
-
jwtPid(
) → DcqlCredentialBuilder - Helper to set the credential type to SD-JWT PID.
-
mDL(
) → DcqlCredentialBuilder - Helper to set the credential type to mDoc Driving License.
-
meta(
String key, dynamic value) → DcqlCredentialBuilder - Sets a metadata value for the credential.
-
multiple(
[bool multiple = true]) → DcqlCredentialBuilder - Sets whether multiple credentials matching this query can be returned.
-
mVRC(
) → DcqlCredentialBuilder - Helper to set the credential type to mDoc mVRC.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requireBinding(
[bool required = true]) → DcqlCredentialBuilder - Sets whether cryptographic holder binding is required.
-
setCredential(
CredentialType credentialType) → DcqlCredentialBuilder - Sets the credential type, updating the format and metadata filter.
-
toString(
) → String -
A string representation of this object.
inherited
-
trustedAuthority(
String type, List< String> values) → DcqlCredentialBuilder - Adds a trusted authority (issuer) for the credential.
-
validate(
) → ValidationResult -
Validates the current state of the query.
Returns a ValidationResult with a list of errors if invalid.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited