DcqlBuilder class
Builds a DCQL query. Use the DcqlBuilder class to build a DCQL query. Check the example directory for more examples.
- Implementers
Constructors
- DcqlBuilder({DcqlValidator? validator, DcqlQuery? query})
Properties
- $_ → DcqlBuilder
-
Separator, returns the current builder instance.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- query → DcqlQuery
-
The DCQL query being built.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validator ↔ DcqlValidator
-
latefinal
Methods
-
build(
{bool skipValidation = false}) → DcqlQuery -
Builds the DCQL query.
If
skipValidationis false, the query will be validated before building. Throws a ValidationException if the query is invalid. -
credential(
String id, {Format? format, CredentialType? type}) → DcqlCredentialBuilder - Adds a new credential to the query.
-
credentialSet(
{bool? required, List< List< ? options}) → DcqlCredentialSetBuilderString> > - Adds a new credential set to the query.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → ValidationResult - Validates the current state of the query. Returns a ValidationResult with a list of errors if invalid.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited