CredentialSet class
Defines a set of credentials that satisfy a query requirement.
This allows for complex logic like "Credential A AND (Credential B OR Credential C)".
- Mixed-in types
Constructors
-
CredentialSet({List<
List< options = const [], bool? required})String> >
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
options
↔ List<
List< String> > -
A list of options, where each option is a list of credential IDs.
getter/setter pair
- required ↔ bool?
-
Whether this credential set is required.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the object to a JSON-serializable value.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> cs) → CredentialSet