credentialSets property
A list of credential sets that define combinations of credentials that satisfy the query.
If null or empty, all credentials in credentials are required.
Implementation
List<CredentialSet>? credentialSets;
A list of credential sets that define combinations of credentials that satisfy the query.
If null or empty, all credentials in credentials are required.
List<CredentialSet>? credentialSets;