ClaimValidator class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
{required Credential< Claim> credential, required DcqlQuery query, required int credentialIndex}) → ValidationResult -
validateId(
Credential< Claim> credential, Claim claim, String contextPath) → ValidationResult -
validatePath(
List path, String contextPath) → ValidationResult -
validateValues(
List< Object> ? values, String contextPath) → ValidationResult
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited