DcqlValidator class
Validates a DCQL query against the specification.
Checks for:
- Unique IDs for credentials and claims.
- Valid references in
claim_setsandcredential_sets. - Correct value types and non-empty paths.
- Required fields.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
DcqlQuery query) → ValidationResult - Validates a DcqlQuery object.
-
validateJson(
String query) → ValidationResult - Validates a JSON string representing a DCQL query.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited